==> kdebase_2.2.2.orig.tar.gz: kdebase-2.2.2/kcontrol/icons/iconthemes.h <==
/**
 * midi.h
 *
 * Copyright (c) 2000 Antonio Larrosa <larrosa@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __midi_h__
#define __midi_h__

#include <kcmodule.h>
#include <qmap.h>
#include <qlistview.h>

class QPushButton;
class DeviceManager;
class KURLRequester;
class QCheckBox;


class IconThemesConfig : public KCModule
{
  Q_OBJECT

public:
  IconThemesConfig(QWidget *parent = 0L, const char *name = 0L);
  virtual ~IconThemesConfig();
  
  void loadThemes();

  void updateRemoveButton();

  void load();
  void save();
  void defaults();
  
  int buttons();
  
protected slots:
  void configChanged();
  void themeSelected(QListViewItem *item);
  void installNewTheme();
  void removeSelectedTheme();
      
private:
  QListViewItem *iconThemeItem(QString name);

  QListView *m_iconThemes;
  KURLRequester *m_themeRequester;
  QPushButton *m_removeButton;

  QLabel *m_previewExec;
  QLabel *m_previewFolder;
  QLabel *m_previewDocument;
  QListViewItem *m_defaultTheme;
  QMap <QString, QString>m_themeNames;

};

#endif

==> kdebase_3.4.3.orig.tar.gz: kdebase-3.4.3/kcontrol/icons/iconthemes.h <==
/**
 * Copyright (c) 2000 Antonio Larrosa <larrosa@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef ICONTHEMES_H
#define ICONTHEMES_H

#include <kcmodule.h>
#include <qmap.h>
#include <klistview.h>

class QPushButton;
class DeviceManager;
class QCheckBox;
class QStringList;


class IconThemesConfig : public KCModule
{
  Q_OBJECT

public:
  IconThemesConfig(QWidget *parent = 0L, const char *name = 0L);
  virtual ~IconThemesConfig();

  void loadThemes();
  bool installThemes(const QStringList &themes, const QString &archiveName);
  QStringList findThemeDirs(const QString &archiveName);

  void updateRemoveButton();

  void load();
  void save();
  void defaults();

  int buttons();

protected slots:
  void themeSelected(QListViewItem *item);
  void installNewTheme();
  void removeSelectedTheme();

private:
  QListViewItem *iconThemeItem(const QString &name);

  KListView *m_iconThemes;
  QPushButton *m_removeButton;

  QLabel *m_previewExec;
  QLabel *m_previewFolder;
  QLabel *m_previewDocument;
  QListViewItem *m_defaultTheme;
  QMap <QString, QString>m_themeNames;
  bool m_bChanged;
};

#endif // ICONTHEMES_H
